@@ -5,10 +5,11 @@
 
 	serif: "serif",
 	"sans-serif": "sans-serif",
-	monospaced: "monospace",
+	monospace: "monospace",
 	cursive: "cursive",
 	fantasy: "fantasy",
 
+	noFormat: "なし",
 	p: "段落",
 	h1: "見出し",
 	h2: "副見出し",
@@ -22,4 +23,4 @@
 	5: "大",
 	6: "特大",
 	7: "超特大"
-})
\ No newline at end of file
+})
