@@ -46,10 +46,10 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 		this._saveInProgress = false;
 	},
 
-	referenceIntegrity: true,  //Flag that defaultly enabled reference integrity tracking.  This way it can also be disabled pogrammatially or declaratively.
+	referenceIntegrity: true, //Flag that defaultly enabled reference integrity tracking.  This way it can also be disabled pogrammatially or declaratively.
 
 	_assert: function(/* boolean */ condition){
-		if(!condition) {
+		if(!condition){
 			throw new Error("assertion failed in ItemFileWriteStore");
 		}
 	},
@@ -68,7 +68,7 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 
 		this._assert(!this._saveInProgress);
 
-		if (!this._loadFinished){
+		if(!this._loadFinished){
 			// We need to do this here so that we'll be able to find out what
 			// identifierAttribute was specified in the data file.
 			this._forceLoad();
@@ -83,10 +83,10 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 			newIdentity = this._arrayOfAllItems.length;
 		}else{
 			newIdentity = keywordArgs[identifierAttribute];
-			if (typeof newIdentity === "undefined"){
+			if(typeof newIdentity === "undefined"){
 				throw new Error("newItem() was not passed an identity for the new item");
 			}
-			if (dojo.isArray(newIdentity)){
+			if(dojo.isArray(newIdentity)){
 				throw new Error("newItem() was not passed an single-valued identity");
 			}
 		}
@@ -185,7 +185,7 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 	
 	_removeArrayElement: function(/* Array */ array, /* anything */ element){
 		var index = dojo.indexOf(array, element);
-		if (index != -1){
+		if(index != -1){
 			array.splice(index, 1);
 			return true;
 		}
@@ -251,12 +251,12 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 						for(var attribute in references[itemId]){
 							var oldValues = this.getValues(containingItem, attribute) || [];
 							var newValues = dojo.filter(oldValues, function(possibleItem){
-							   return !(this.isItem(possibleItem) && this.getIdentity(possibleItem) == identity);
+								return !(this.isItem(possibleItem) && this.getIdentity(possibleItem) == identity);
 							}, this);
 							//Remove the note of the reference to the item and set the values on the modified attribute.
 							this._removeReferenceFromMap(item, containingItem, attribute); 
 							if(newValues.length < oldValues.length){
-								this.setValues(containingItem, attribute, newValues);
+								this._setValueOrValues(containingItem, attribute, newValues, true);
 							}
 						}
 					}
@@ -348,7 +348,7 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 
 			if(this.referenceIntegrity && oldValueOrValues){
 				var oldValues = oldValueOrValues;
-				if (!dojo.isArray(oldValues)){
+				if(!dojo.isArray(oldValues)){
 					oldValues = [oldValues];
 				}
 				for(var i = 0; i < oldValues.length; i++){
@@ -505,7 +505,7 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 			}
 		}
 	},
-						   
+	
 	_getValueOrValues: function(/* item */ item, /* attribute-name-string */ attribute){
 		var valueOrValues = undefined;
 		if(this.hasAttribute(item, attribute)){
@@ -535,7 +535,7 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 			if(typeof value === "object"){
 				for(var type in this._datatypeMap){
 					var typeMap = this._datatypeMap[type];
-					if (dojo.isObject(typeMap) && !dojo.isFunction(typeMap)){
+					if(dojo.isObject(typeMap) && !dojo.isFunction(typeMap)){
 						if(value instanceof typeMap.type){
 							if(!typeMap.serialize){
 								throw new Error("ItemFileWriteStore:  No serializer defined for type mapping: [" + type + "]");
@@ -572,7 +572,7 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 			if(item !== null){
 				var serializableItem = {};
 				for(var key in item){
-					if(key !== this._storeRefPropName && key !== this._itemNumPropName){
+					if(key !== this._storeRefPropName && key !== this._itemNumPropName && key !== this._reverseRefMap && key !== this._rootItemPropName){
 						var attribute = key;
 						var valueArray = this.getValues(item, attribute);
 						if(valueArray.length == 1){
@@ -634,11 +634,11 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 				keywordArgs.onComplete.call(scope);
 			}
 		};
-		var saveFailedCallback = function(){
+		var saveFailedCallback = function(err){
 			self._saveInProgress = false;
 			if(keywordArgs && keywordArgs.onError){
 				var scope = keywordArgs.scope || dojo.global;
-				keywordArgs.onError.call(scope);
+				keywordArgs.onError.call(scope, err);
 			}
 		};
 		
@@ -662,50 +662,23 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 		this._assert(!this._saveInProgress);
 
 		var identity;
-		for(identity in this._pending._newItems){
-			var newItem = this._pending._newItems[identity];
-			newItem[this._storeRefPropName] = null;
-			// null out the new item, but don't change the array index so
-			// so we can keep using _arrayOfAllItems.length.
-			this._arrayOfAllItems[newItem[this._itemNumPropName]] = null;
-			if(newItem[this._rootItemPropName]){
-				this._removeArrayElement(this._arrayOfTopLevelItems, newItem);
-			}
-			if(this._itemsByIdentity){
-				delete this._itemsByIdentity[identity];
-			}
-		}
 		for(identity in this._pending._modifiedItems){
 			// find the original item and the modified item that replaced it
-			var originalItem = this._pending._modifiedItems[identity];
+			var copyOfItemState = this._pending._modifiedItems[identity];
 			var modifiedItem = null;
 			if(this._itemsByIdentity){
 				modifiedItem = this._itemsByIdentity[identity];
 			}else{
 				modifiedItem = this._arrayOfAllItems[identity];
 			}
-			
-			// make the original item into a full-fledged item again
-			originalItem[this._storeRefPropName] = this;
-			modifiedItem[this._storeRefPropName] = null;
-
-			// replace the modified item with the original one
-			var arrayIndex = modifiedItem[this._itemNumPropName];
-			this._arrayOfAllItems[arrayIndex] = originalItem;
-			
-			if(modifiedItem[this._rootItemPropName]){
-				var i;
-				for (i = 0; i < this._arrayOfTopLevelItems.length; i++) {
-					var possibleMatch = this._arrayOfTopLevelItems[i];
-					if (this.getIdentity(possibleMatch) == identity){
-						this._arrayOfTopLevelItems[i] = originalItem;
-						break;
-					}
-				}
+	
+			// Restore the original item into a full-fledged item again, we want to try to 
+			// keep the same object instance as if we don't it, causes bugs like #9022.
+			copyOfItemState[this._storeRefPropName] = this;
+			for(key in modifiedItem){
+				delete modifiedItem[key];
 			}
-			if(this._itemsByIdentity){
-				this._itemsByIdentity[identity] = originalItem;
-			}			
+			dojo.mixin(modifiedItem, copyOfItemState);
 		}
 		var deletedItem;
 		for(identity in this._pending._deletedItems){
@@ -719,12 +692,12 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 				delete deletedItem["backup_" + this._reverseRefMap];
 			}
 			this._arrayOfAllItems[index] = deletedItem;
-			if (this._itemsByIdentity) {
+			if(this._itemsByIdentity){
 				this._itemsByIdentity[identity] = deletedItem;
 			}
 			if(deletedItem[this._rootItemPropName]){
 				this._arrayOfTopLevelItems.push(deletedItem);
-			}	  
+			}
 		}
 		//We have to pass through it again and restore the reference maps after all the
 		//undeletes have occurred.
@@ -744,6 +717,20 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 			}
 		}
 
+		for(identity in this._pending._newItems){
+			var newItem = this._pending._newItems[identity];
+			newItem[this._storeRefPropName] = null;
+			// null out the new item, but don't change the array index so
+			// so we can keep using _arrayOfAllItems.length.
+			this._arrayOfAllItems[newItem[this._itemNumPropName]] = null;
+			if(newItem[this._rootItemPropName]){
+				this._removeArrayElement(this._arrayOfTopLevelItems, newItem);
+			}
+			if(this._itemsByIdentity){
+				delete this._itemsByIdentity[identity];
+			}
+		}
+
 		this._pending = {
 			_newItems:{}, 
 			_modifiedItems:{}, 
@@ -759,13 +746,13 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 			var identity = this.getIdentity(item);
 			return new Boolean(this._pending._newItems[identity] || 
 				this._pending._modifiedItems[identity] ||
-				this._pending._deletedItems[identity]); // boolean
+				this._pending._deletedItems[identity]).valueOf(); // boolean
 		}else{
 			// return true if the store is dirty -- which means return true
 			// if there are any new items, dirty items, or modified items
 			if(!this._isEmpty(this._pending._newItems) || 
-			   !this._isEmpty(this._pending._modifiedItems) ||
-			   !this._isEmpty(this._pending._deletedItems)){
+				!this._isEmpty(this._pending._modifiedItems) ||
+				!this._isEmpty(this._pending._deletedItems)){
 				return true;
 			}
 			return false; // boolean
@@ -796,5 +783,24 @@ dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
 		
 		// No need to do anything. This method is here just so that the 
 		// client code can connect observers to it. 
+	},
+
+	close: function(/* object? */ request){
+		 // summary:
+		 //		Over-ride of base close function of ItemFileReadStore to add in check for store state.
+		 // description:
+		 //		Over-ride of base close function of ItemFileReadStore to add in check for store state.
+		 //		If the store is still dirty (unsaved changes), then an error will be thrown instead of
+		 //		clearing the internal state for reload from the url.
+
+		 //Clear if not dirty ... or throw an error
+		 if(this.clearOnClose){
+			 if(!this.isDirty()){
+				 this.inherited(arguments);
+			 }else{
+				 //Only throw an error if the store was dirty and we were loading from a url (cannot reload from url until state is saved).
+				 throw new Error("dojo.data.ItemFileWriteStore: There are unsaved changes present in the store.  Please save or revert the changes before invoking close.");
+			 }
+		 }
 	}
 });
