@@ -15,15 +15,11 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id $
  */
 
-/**
- * Test helper
- */
-require_once dirname(dirname(dirname(__FILE__))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Controller_AllTests::main');
 }
@@ -36,6 +32,7 @@ require_once 'FrontTest.php';
 require_once 'Plugin/ActionStackTest.php';
 require_once 'Plugin/BrokerTest.php';
 require_once 'Plugin/ErrorHandlerTest.php';
+require_once 'Plugin/PutHandlerTest.php';
 require_once 'Request/Apache404Test.php';
 require_once 'Request/HttpTest.php';
 require_once 'Request/HttpTestCaseTest.php';
@@ -46,14 +43,17 @@ require_once 'Router/RouteTest.php';
 require_once 'Router/Route/ModuleTest.php';
 require_once 'Router/Route/RegexTest.php';
 require_once 'Router/Route/StaticTest.php';
+require_once 'Router/Route/HostnameTest.php';
+require_once 'Router/Route/ChainTest.php';
 require_once 'Router/RewriteTest.php';
 
 /**
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Controller
  */
 class Zend_Controller_AllTests
 {
@@ -74,6 +74,7 @@ class Zend_Controller_AllTests
         $suite->addTestSuite('Zend_Controller_Plugin_ActionStackTest');
         $suite->addTestSuite('Zend_Controller_Plugin_BrokerTest');
         $suite->addTestSuite('Zend_Controller_Plugin_ErrorHandlerTest');
+        $suite->addTestSuite('Zend_Controller_Plugin_PutHandlerTest');
         $suite->addTestSuite('Zend_Controller_Request_Apache404Test');
         $suite->addTestSuite('Zend_Controller_Request_HttpTest');
         $suite->addTestSuite('Zend_Controller_Request_HttpTestCaseTest');
@@ -84,6 +85,8 @@ class Zend_Controller_AllTests
         $suite->addTestSuite('Zend_Controller_Router_Route_ModuleTest');
         $suite->addTestSuite('Zend_Controller_Router_Route_RegexTest');
         $suite->addTestSuite('Zend_Controller_Router_Route_StaticTest');
+        $suite->addTestSuite('Zend_Controller_Router_Route_HostnameTest');
+        $suite->addTestSuite('Zend_Controller_Router_Route_ChainTest');
         $suite->addTestSuite('Zend_Controller_Router_RewriteTest');
 
         return $suite;
