@@ -98,6 +98,6 @@ abstract class Zend_Db_Adapter_Pdo_TestCommon extends Zend_Db_Adapter_TestCommon
     {
         $string = "1\0";
         $value  = $this->_db->quote($string);
-        $this->assertEquals("'1\\000'", $value);
+        $this->assertNotContains("\0", $value);
     }
 }
