@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,42 +15,37 @@
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: StaticTest.php 5484 2007-06-28 21:38:50Z bkarwin $
+ * @version    $Id$
  */
 
 
 /**
  * PHPUnit_Framework_TestCase
  */
-require_once 'PHPUnit/Framework/TestCase.php';
-
-/**
- * PHPUnit_Util_Filter
- */
-require_once 'PHPUnit/Util/Filter.php';
-
-PHPUnit_Util_Filter::addFileToFilter(__FILE__);
 
 /**
  * @see Zend_Db_Table_Row_TestMockRow
  */
-require_once 'Zend/Db/Table/Row/TestMockRow.php';
+require_once dirname(__FILE__) . '/../_files/My/ZendDbTable/Row/TestMockRow.php';
 
 /**
  * @category   Zend
  * @package    Zend_Db
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Db
+ * @group      Zend_Db_Table
+ * @group      Zend_Db_Table_Relationships
  */
 class Zend_Db_Table_Relationships_StaticTest extends PHPUnit_Framework_TestCase
 {
 
     public function testTableRelationshipsFindDependentMagic()
     {
-        $row = new Zend_Db_Table_Row_TestMockRow();
+        $row = new My_ZendDbTable_Row_TestMockRow();
 
         $this->assertNull($row->dependentTable);
         $this->assertNull($row->ruleKey);
@@ -67,7 +61,7 @@ class Zend_Db_Table_Relationships_StaticTest extends PHPUnit_Framework_TestCase
 
     public function testTableRelationshipsFindParentMagic()
     {
-        $row = new Zend_Db_Table_Row_TestMockRow();
+        $row = new My_ZendDbTable_Row_TestMockRow();
 
         $this->assertNull($row->parentTable);
         $this->assertNull($row->ruleKey);
@@ -83,7 +77,7 @@ class Zend_Db_Table_Relationships_StaticTest extends PHPUnit_Framework_TestCase
 
     public function testTableRelationshipsFindManyToManyMagic()
     {
-        $row = new Zend_Db_Table_Row_TestMockRow();
+        $row = new My_ZendDbTable_Row_TestMockRow();
 
         $this->assertNull($row->matchTable);
         $this->assertNull($row->intersectionTable);
